@@ -6,12 +6,13 @@ from linora.image._image_draw import draw_point
 
 __all__ = ['noise_gaussian', 'noise_poisson', 'noise_color']
 
+
 def noise_gaussian(image, scale=1, mean=0.0, std=1.0):
     """Gaussian noise apply to image.
     
     new pixel = image + gaussian_noise * scale
     Args:
-        image: a Image instance.
+        image: a PIL instance.
         scale: if int or float, value multiply with gaussian noise.
                if tuple or list, randomly picked in the interval
                `[scale[0], scale[1])`, value multiply with gaussian noise.
@@ -22,7 +23,7 @@ def noise_gaussian(image, scale=1, mean=0.0, std=1.0):
              if tuple or list, randomly picked in the interval
              `[std[0], std[1])`, value is gaussian distribution std.
     Returns:
-        a Image instance.
+        a PIL instance.
     """
     if isinstance(scale, (tuple, list)):
         scale = np.random.uniform(scale[0], scale[1])
@@ -32,12 +33,13 @@ def noise_gaussian(image, scale=1, mean=0.0, std=1.0):
         mean = np.random.uniform(mean[0], mean[1])
     return image.point(lambda x:int((np.random.normal(mean, std, size=1)*scale+x).round()))
 
+
 def noise_poisson(image, scale=1, lam=1.0):
     """Poisson noise apply to image.
     
     new pixel = image + poisson_noise * scale
     Args:
-        image: a Image instance.
+        image: a PIL instance.
         scale: if int or float, value multiply with poisson noise.
                if tuple or list, randomly picked in the interval
                `[scale[0], scale[1])`, value multiply with poisson noise.
@@ -45,7 +47,7 @@ def noise_poisson(image, scale=1, lam=1.0):
              if tuple or list, randomly picked in the interval
              `[lam[0], lam[1])`, value is poisson distribution lambda.
     Returns:
-        a Image instance.
+        a PIL instance.
     """
     if isinstance(scale, (tuple, list)):
         scale = np.random.uniform(scale[0], scale[1])
@@ -53,6 +55,7 @@ def noise_poisson(image, scale=1, lam=1.0):
         lam = np.random.uniform(std[0], std[1])
     return image.point(lambda x:int((np.random.poisson(lam, size=1)*scale+x).round()))
 
+
 def noise_color(image, white_prob=0.05, black_prob=0.05, rainbow_prob=0):
     """Mask noise apply to image with color.
     
@@ -71,12 +74,12 @@ def noise_color(image, white_prob=0.05, black_prob=0.05, rainbow_prob=0):
     and randomly assigning these pixels to 0 or 255.
     
     Args:
-        image: a Image instance.
+        image: a PIL instance.
         white_prob: white pixel prob.
         black_prob: black pixel prob.
         rainbow_prob: rainbow color pixel prob.
     Returns:
-        a Image instance.
+        a PIL instance.
     """
     img = image.copy()
     axis = [(i,j) for i in range(image.width) for j in range(image.height)]
