@@ -4,15 +4,15 @@ class ImageResizeAug(object):
     def __init__(self, image=None):
         self.image = image
         
-    def resize(self, size, method=ResizeMethod.BILINEAR):
+    def resize(self, size, method=ResizeMode.BILINEAR):
         """Returns a resized copy of this image.
     
         Args:
-        size: The requested size in pixels, as a 2-tuple: (width, height).
-        method: An optional resampling filter. see la.image.ResizeMethod.
+            size: The requested size in pixels, as a 2-tuple: (width, height).
+            method: An optional resampling filter. see la.image.ResizeMode.
 
         Returns:
-            a Image instance.
+            a PIL instance.
         """
         self.image = resize(self.image, size, method)
         return self
