@@ -2,10 +2,11 @@ import numpy as np
 
 __all__ = ['normal_loss', 'mean_absolute_error', 'mean_squared_error',
            'mean_absolute_percentage_error', 'hinge', 'explained_variance_score',
-           'median_absolute_error', 'r2_score', 'regression_report',
+           'median_absolute_error', 'r2_score', 'report_regression',
            'mean_relative_error', 'poisson', 'log_cosh_error'
           ]
 
+
 def normal_loss(y_true, y_pred, k, log=False, root=False):
     """Mean normal error regression loss.
     
@@ -25,9 +26,10 @@ def normal_loss(y_true, y_pred, k, log=False, root=False):
     else:
         loss = np.power(np.abs(y_true-y_pred), k).mean()
     if root:
-        loss = np.sqrt(loss, 1/k)
+        loss = np.power(loss, 1/k)
     return loss
 
+
 def mean_absolute_error(y_true, y_pred, log=False):
     """Mean absolute error regression loss.
     
@@ -40,6 +42,7 @@ def mean_absolute_error(y_true, y_pred, log=False):
     """
     return normal_loss(y_true, y_pred, k=1, log=log, root=False)
 
+
 def mean_squared_error(y_true, y_pred, log=False, root=False):
     """Mean squared error regression loss.
     
@@ -53,6 +56,7 @@ def mean_squared_error(y_true, y_pred, log=False, root=False):
     """
     return normal_loss(y_true, y_pred, k=2, log=log, root=root)
 
+
 def mean_absolute_percentage_error(y_true, y_pred):
     """Mean absolute percentage error regression loss.
     
@@ -64,7 +68,10 @@ def mean_absolute_percentage_error(y_true, y_pred):
     """
     y_true = np.array(y_true)
     y_pred = np.array(y_pred)
-    return np.abs((y_true-y_pred)/y_true).mean()
+    value = np.abs(y_pred - y_true)
+    y_true[np.where(y_true==0)] = 1
+    return (value/np.abs(y_true)).mean()
+
 
 def hinge(y_true, y_pred, k=1):
     """hinge regression loss.
@@ -80,6 +87,7 @@ def hinge(y_true, y_pred, k=1):
     y_pred = np.array(y_pred)
     return np.power((1-y_true*y_pred).clip(min=0), k).mean()
 
+
 def explained_variance_score(y_true, y_pred):
     """explained variance regression loss.
     
@@ -93,6 +101,7 @@ def explained_variance_score(y_true, y_pred):
     y_pred = np.array(y_pred)
     return 1-(y_true-y_pred).std()**2/y_true.std()**2
 
+
 def median_absolute_error(y_true, y_pred):
     """Median absolute error regression loss.
     
@@ -104,6 +113,7 @@ def median_absolute_error(y_true, y_pred):
     """
     return np.median(np.abs(np.array(y_true)-np.array(y_pred)))
 
+
 def r2_score(y_true, y_pred):
     """r2 regression loss.
     
@@ -117,13 +127,15 @@ def r2_score(y_true, y_pred):
     y_pred = np.array(y_pred)
     return 1-np.power(y_true-y_pred, 2).sum()/np.power(y_true-y_true.mean(), 2).sum()
 
-def regression_report(y_true, y_pred, printable=False, printinfo='Regression Report'):
-    """
+
+def report_regression(y_true, y_pred, printable=False):
+    """regression report
     Args:
         y_true: pd.Series or array or list, ground truth (correct) labels.
         y_pred: pd.Series or array or list, predicted labels.
+        printable: bool, print report.
     Returns:
-        regression report.
+        dict, regression report.
     """
     result = {'mean_absolute_error':mean_absolute_error(y_true, y_pred),
               'mean_squared_error':mean_squared_error(y_true, y_pred),
@@ -134,7 +146,7 @@ def regression_report(y_true, y_pred, printable=False, printinfo='Regression Rep
               'r2_score':r2_score(y_true, y_pred)
              }
     if printable:
-        print("\n{}".format(printinfo))
+        print("\nRegression Report")
         print("mean_absolute_error: %.4f" % result['mean_absolute_error'])
         print("mean_squared_error: %.4f" % result['mean_squared_error'])
         print("mean_absolute_percentage_error: %.4f" % result['mean_absolute_percentage_error'])
@@ -144,6 +156,7 @@ def regression_report(y_true, y_pred, printable=False, printinfo='Regression Rep
         print("r2_score: %.4f" % result['r2_score'])
     return result
 
+
 def mean_relative_error(y_true, y_pred, normalizer):
     """Computes the mean relative error by normalizing with the given values.
     
@@ -156,6 +169,7 @@ def mean_relative_error(y_true, y_pred, normalizer):
     """
     return (np.abs(np.array(y_true)-np.array(y_pred))/np.array(normalizer)).mean()
 
+
 def poisson(y_true, y_pred):
     """Computes the Poisson loss between y_true and y_pred.
     
@@ -167,6 +181,7 @@ def poisson(y_true, y_pred):
     """
     return np.mean(np.array(y_pred) - np.array(y_true) * np.log(np.array(y_pred)+ 1e-7))
 
+
 def log_cosh_error(y_true, y_pred):
     """Computes the logarithm of the hyperbolic cosine of the prediction error.
     
